pref

Macro pref 

macro_rules! pref {
    ($string:tt $(, gecko = $_:tt)?) => { ... };
    ($string:tt, servo = $value:tt) => { ... };
}
Returns the value of a preference exposed to the style crate. It allows overriding the result for either Gecko or Servo, which is useful when the preference only exists for one of them.